@@ -178,7 +178,7 @@ if [ -n "$LIBGIT2_VERSION" ]; then
     wget https://github.com/libgit2/libgit2/archive/refs/tags/v$LIBGIT2_VERSION.tar.gz -N -O $FILENAME.tar.gz
     tar xf $FILENAME.tar.gz
     cd $FILENAME
-    mkdir build -p
+    mkdir -p build
     cd build
     if [ "$KERNEL" = "Darwin" ] && [ "$CIBUILDWHEEL" = "1" ]; then
         CMAKE_PREFIX_PATH=$OPENSSL_PREFIX:$PREFIX cmake .. \
@@ -269,7 +269,7 @@ if [ "$1" = "mypy" ]; then
         $PREFIX/bin/pip install $WHEELDIR/pygit2*-$PYTHON_TAG-*.whl
     fi
     $PREFIX/bin/pip install -r requirements-test.txt
-    $PREFIX/bin/mypy pygit2
+    $PREFIX/bin/mypy pygit2 test
 fi
 
 # Test .pyi stub file
