@@ -35,7 +35,6 @@
 #include "utils.h"
 #include "repository.h"
 #include "oid.h"
-#include "options.h"
 #include "filter.h"
 
 PyObject *GitError;
@@ -439,7 +438,6 @@ PyMethodDef module_methods[] = {
     {"hash", hash, METH_VARARGS, hash__doc__},
     {"hashfile", hashfile, METH_VARARGS, hashfile__doc__},
     {"init_file_backend", init_file_backend, METH_VARARGS, init_file_backend__doc__},
-    {"option", option, METH_VARARGS, option__doc__},
     {"reference_is_valid_name", reference_is_valid_name, METH_O, reference_is_valid_name__doc__},
     {"tree_entry_cmp", tree_entry_cmp, METH_VARARGS, tree_entry_cmp__doc__},
     {"filter_register", (PyCFunction)filter_register, METH_VARARGS | METH_KEYWORDS, filter_register__doc__},
@@ -473,39 +471,6 @@ PyInit__pygit2(void)
     ADD_CONSTANT_INT(m, LIBGIT2_VER_REVISION)
     ADD_CONSTANT_STR(m, LIBGIT2_VERSION)
 
-    /* libgit2 options */
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_MWINDOW_SIZE);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_MWINDOW_SIZE);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_MWINDOW_MAPPED_LIMIT);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_MWINDOW_MAPPED_LIMIT);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_SEARCH_PATH);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_SEARCH_PATH);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_CACHE_OBJECT_LIMIT);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_CACHE_MAX_SIZE);
-    ADD_CONSTANT_INT(m, GIT_OPT_ENABLE_CACHING);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_CACHED_MEMORY);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_TEMPLATE_PATH);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_TEMPLATE_PATH);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_SSL_CERT_LOCATIONS);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_USER_AGENT);
-    ADD_CONSTANT_INT(m, GIT_OPT_ENABLE_STRICT_OBJECT_CREATION);
-    ADD_CONSTANT_INT(m, GIT_OPT_ENABLE_STRICT_SYMBOLIC_REF_CREATION);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_SSL_CIPHERS);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_USER_AGENT);
-    ADD_CONSTANT_INT(m, GIT_OPT_ENABLE_OFS_DELTA);
-    ADD_CONSTANT_INT(m, GIT_OPT_ENABLE_FSYNC_GITDIR);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_WINDOWS_SHAREMODE);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_WINDOWS_SHAREMODE);
-    ADD_CONSTANT_INT(m, GIT_OPT_ENABLE_STRICT_HASH_VERIFICATION);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_ALLOCATOR);
-    ADD_CONSTANT_INT(m, GIT_OPT_ENABLE_UNSAVED_INDEX_SAFETY);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_PACK_MAX_OBJECTS);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_PACK_MAX_OBJECTS);
-    ADD_CONSTANT_INT(m, GIT_OPT_DISABLE_PACK_KEEP_FILE_CHECKS);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_OWNER_VALIDATION);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_OWNER_VALIDATION);
-    ADD_CONSTANT_INT(m, GIT_OPT_GET_MWINDOW_FILE_LIMIT);
-    ADD_CONSTANT_INT(m, GIT_OPT_SET_MWINDOW_FILE_LIMIT);
 
     /* Exceptions */
     ADD_EXC(m, GitError, NULL);
