@@ -25,9 +25,9 @@
 
 """Tests for note objects."""
 
-from pygit2 import Signature
 import pytest
 
+from pygit2 import Blob, Repository, Signature
 
 NOTE = ('6c8980ba963cad8b25a9bcaf68d4023ee57370d8', 'note message')
 
@@ -45,24 +45,26 @@ NOTES = [
 ]
 
 
-def test_create_note(barerepo):
+def test_create_note(barerepo: Repository) -> None:
     annotated_id = barerepo.revparse_single('HEAD~3').id
     author = committer = Signature('Foo bar', 'foo@bar.com', 12346, 0)
     note_id = barerepo.create_note(NOTE[1], author, committer, str(annotated_id))
     assert NOTE[0] == note_id
 
+    note = barerepo[note_id]
+    assert isinstance(note, Blob)
     # check the note blob
-    assert NOTE[1].encode() == barerepo[note_id].data
+    assert NOTE[1].encode() == note.data
 
 
-def test_lookup_note(barerepo):
+def test_lookup_note(barerepo: Repository) -> None:
     annotated_id = str(barerepo.head.target)
     note = barerepo.lookup_note(annotated_id)
     assert NOTES[0][0] == note.id
     assert NOTES[0][1] == note.message
 
 
-def test_remove_note(barerepo):
+def test_remove_note(barerepo: Repository) -> None:
     head = barerepo.head
     note = barerepo.lookup_note(str(head.target))
     author = committer = Signature('Foo bar', 'foo@bar.com', 12346, 0)
@@ -71,11 +73,14 @@ def test_remove_note(barerepo):
         barerepo.lookup_note(str(head.target))
 
 
-def test_iterate_notes(barerepo):
+def test_iterate_notes(barerepo: Repository) -> None:
     for i, note in enumerate(barerepo.notes()):
-        assert NOTES[i] == (note.id, note.message, note.annotated_id)
+        note_id, message, annotated_id = NOTES[i]
+        assert note_id == note.id
+        assert message == note.message
+        assert annotated_id == note.annotated_id
 
 
-def test_iterate_non_existing_ref(barerepo):
+def test_iterate_non_existing_ref(barerepo: Repository) -> None:
     with pytest.raises(KeyError):
-        barerepo.notes('refs/notes/bad_ref')
+        barerepo.notes('refs/notes/bad_ref')  # type: ignore
